@@ -10,17 +10,18 @@ my $calculator = qr{
     <Answer>
 
     <objrule: Answer>
-        <[Operand=Mult]> ** <[Operator=(\+|\-)]>
+        <[Operand=Mult]>+ % <[Operator=(\+|\-)]>
 
     <objrule: Mult>
-        <[Operand=Pow]> ** <[Operator=( [*/%] )]>
+        <[Operand=Pow]>+ % <[Operator=( [*/%] )]>
 
     <objrule: Pow>
-        <[Operand=Term]> ** <Operator=(\^)> 
+        <[Operand=Term]>+ % <Operator=(\^)>
 
     <objrule: Term>
-                              <MATCH=Literal>
-      | <.OpenParen=(  \( )>  <MATCH=Answer>  <.CloseParen=( \) )>
+        <MATCH=Literal>
+      | <Sign=(-)> \( <Operand= Answer> \)
+      | <MATCH=Answer>
 
     <token: Literal>
         <MATCH=( [+-]? \d++ (?: \. \d++ )?+ )>
